@@ -4,15 +4,20 @@ varMarkdown <- function(effect, mod, modsum, statistic='t', B=1, CI=B, pe=2)
 
   if (is.numeric(pe)){
     pestat = (abs(coef(modsum)[effect,'t'])^2*1)/(abs(coef(modsum)[effect,'t'])^2*1 + mod$df.residual)
-    results = paste0(results, '*p$\\eta^2$* = ', sprintf(paste0('%.',pe,'f'), pestat), ', ')
-  }  
-  
+    if ((floor(pestat * 100) / 100) < 0.01) {
+      results = paste0(results, '*$\\eta_p^2$* <  .001, ')
+    } else if ((floor(pestat * 100) / 100) == 0.00) {
+      results = paste0(results, '*$\\eta_p^2$* =  .001, ')
+    } else {
+      results = paste0(results, '*$\\eta_p^2$* = ', sprintf(paste0('%.',pe,'f'), pestat), ', ')
+    }  
+  }
   if (is.numeric(B)){
     results = paste0(results,'*b* = ', sprintf(paste0('%.',B,'f'),coef(mod)[effect]), ', ')
   }
   
   if (is.numeric(CI)){
-    results = paste0(results,'*95% CI(B)* = [', sprintf(paste0('%.',CI,'f'),confint(mod)[effect,1]), ',', sprintf(paste0('%.',CI,'f'),confint(mod)[effect,2]), '], ')
+    results = paste0(results,'*95% CI* = [', sprintf(paste0('%.',CI,'f'),confint(mod)[effect,1]), ',', sprintf(paste0('%.',CI,'f'),confint(mod)[effect,2]), '], ')
   }
   
   #add t
